<?php
/**
 * The header for our theme.
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Miami
 */

?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="format-detection" content="telephone=no" />
	<meta name="apple-mobile-web-app-capable" content="yes" />
	<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1.0, user-scalable=no, minimal-ui"/>
	<?php wp_head(); ?>
</head>

<?php

$type_logo  = cs_get_option( 'type_logo');
$logo_text  = cs_get_option( 'logo_text');
$logo_image = cs_get_option( 'logo_image');

$header_social = cs_get_option( 'header_social'); ?>

<body <?php body_class(); ?> >
	
<?php if ( cs_get_option( 'show_preloader' ) ) { ?>
	<!-- LOADER -->
	<div id="loading">
		<div id="loading-center">
			<div id="loading-center-absolute">
				<div class="cssload-wrap">
					<div class="cssload-cssload-spinner"></div>
				</div>
			</div>
		</div>
	</div>
<?php } ?>

<!-- HEADER -->
<header class="header clearfix">

	<!--CENTERED MENU-->
	<div class="centered-menu-wrap">
		<div class="logo-block mobile">
			<a class="logo" href="<?php echo esc_url( home_url( '/' ) ); ?>">
				<?php if ( $type_logo == 'image' ) {
					if( ! empty( $logo_image ) ) { ?>
						<img class="f-logo" src="<?php echo esc_url( $logo_image ); ?>" alt="<?php echo esc_attr( get_bloginfo("name") ); ?>">
					<?php } else { 
						esc_html_e( 'Add image logo','miami' ); 
					}
				} else { ?>
					<span class="logo-text">
						<?php if( ! empty( $logo_text ) ) {
							echo esc_html( $logo_text );
						} else {
							esc_html_e('Miami','miami');
						} ?>
					</span>
				<?php } ?>
			</a>
		</div>
		<nav class="main-nav">
			<!-- Site menu -->
			<?php if( has_nav_menu( 'topleft' ) ) {

				$args_menu = array(
					'theme_location'  => 'topleft',
					'container'       => '',
					'container_class' => '',
					'menu_class'      => 'anchor-navigation',
					'depth'           => 3,
					'walker'          => new Miami_Menu_Walker()
				);

				wp_nav_menu( $args_menu );

			} elseif ( ! has_nav_menu( 'topleft' ) ) { ?>

				<div class="nav-item no_register_menu">
					<?php esc_html_e( 'Please register Menu from ', 'miami' ); ?>
					<a href="<?php echo esc_url( admin_url( 'nav-menus.php' ) ); ?>" target="_blank"><?php esc_html_e( 'Appearance &gt; Menus','miami' ); ?></a>
				</div>

			<?php } //endif ?>

			<div class="logo-block">
				<a class="logo" href="<?php echo esc_url( home_url( '/' ) ); ?>">
					<?php if ( $type_logo == 'image' ) {
						if( ! empty( $logo_image ) ) { ?>
							<img class="f-logo" src="<?php echo esc_url( $logo_image ); ?>" alt="<?php echo esc_attr( get_bloginfo( 'name' ) ); ?>">
						<?php } else { esc_html_e( 'Add image logo','miami' ); }
					} else { ?>
						<span class="logo-text">
							<?php if( ! empty( $logo_text ) ) {
								echo esc_html( $logo_text );
							} else {
								esc_html_e( 'Miami','miami' );
							} ?>
						</span>
					<?php } ?>
				</a>
			</div>

			<?php if( has_nav_menu( 'topright' ) ) {

				$args_menu = array(
					'theme_location'  => 'topright',
					'container'       => '',
					'container_class' => '',
					'menu_class'      => 'anchor-navigation',
					'depth'           => 3,
					'walker'          => new Miami_Menu_Walker()
				);

				wp_nav_menu( $args_menu );

			} elseif ( ! has_nav_menu( 'topright' ) ) { ?>

				<div class="nav-item no_register_menu">
					<?php esc_html_e( 'Please register Menu from ','miami' ); ?>
					<a href="<?php echo esc_url( admin_url( 'nav-menus.php' ) ); ?>" target="_blank"><?php esc_html_e( 'Appearance &gt; Menus','miami' ); ?></a>
				</div>

			<?php } //endif ?>

		</nav>
	</div>

	<button class="cmn-toggle-switch"><span></span></button>
</header>