<?php
/**
 * Miami Theme Customizer.
 *
 * @package miami
 */

if ( ! function_exists('miami_customize_register' ) ) :
	/**
	 * Add postMessage support for site title and description for the Theme Customizer.
	 *
	 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
	 */
	function miami_customize_register( $wp_customize ) {

		require_once get_template_directory() . '/inc/alpha-color-picker/alpha-color-picker.php';	

		// Menu Background Color
		$wp_customize->add_setting( 'header_text_color', array(
			'default' => '#FFFFFF'
		), array('sanitize_callback' => '__return_false') );
		// add color picker control
		$wp_customize->add_control( new WP_Customize_Color_Control(
			$wp_customize,
			'header_text_color',
			array(
				'label'      => esc_html__( 'Text Header Color', 'miami' ),
				'section'    => 'colors',
				'settings'   => 'header_text_color',
				'priority'   => 3
			)
		));
		// end menu background  color

		// Main Color
		$wp_customize->add_setting( 'main_color', array(
			'default' => '#F15378'
		), array('sanitize_callback' => '__return_false') );
		// add color picker control
		$wp_customize->add_control( new WP_Customize_Color_Control(
			$wp_customize,
			'main_color',
			array(
				'label'      => esc_html__( 'Main color', 'miami' ),
				'section'    => 'colors',
				'settings'   => 'main_color',
				'priority'   => 4
			)
		));
		// end base front color

		// Front Color Text
		$wp_customize->add_setting( 'front_color_settings', array(
			'default' => '#fff'
		), array('sanitize_callback' => '__return_false') );
		// add color picker control
		$wp_customize->add_control( new WP_Customize_Color_Control(
			$wp_customize,
			'front_color_settings',
			array(
				'label'      => esc_html__( 'Front Color Text', 'miami' ),
				'section'    => 'colors',
				'settings'   => 'front_color_settings',
				'priority'   => 5
			)
		));
		// end front color text
		
		// Base background Color
		$wp_customize->add_setting( 'base_bg_color_settings', array(
			'default' => '#283152'
		), array('sanitize_callback' => '__return_false') );
		// add color picker control
		$wp_customize->add_control( new WP_Customize_Color_Control(
			$wp_customize,
			'base_bg_color_settings',
			array(
				'label'      => esc_html__( 'Base Color', 'miami' ),
				'section'    => 'colors',
				'settings'   => 'base_bg_color_settings',
				'priority'   => 7
			)
		));
		// end base background color

		// $wp_customize->get_control('header_textcolor')->label = esc_html__( 'Menu Links Color', 'miami' );
		$wp_customize->get_control('main_color')->label = esc_html__( 'Main color', 'miami' );

		//custom
		$wp_customize->get_setting( 'header_text_color' )->transport = 'postMessage';
		$wp_customize->get_setting( 'main_color' )->transport = 'postMessage';
		$wp_customize->get_setting( 'front_color_settings' )->transport = 'postMessage';
		$wp_customize->get_setting( 'base_bg_color_settings' )->transport = 'postMessage';

		// default
		$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
		$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
		$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
		$wp_customize->get_setting( 'header_image' )->transport     = 'postMessage';
		$wp_customize->get_setting( 'background_color' )->transport = 'postMessage';
		$wp_customize->get_setting( 'background_image' )->transport = 'postMessage';
	}
endif;
add_action( 'customize_register', 'miami_customize_register' );

if ( ! function_exists( 'miami_customize_preview_js' ) ) :
	/**
	 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
	 */
	function miami_customize_preview_js() {
		wp_enqueue_script( 'miami_customizer', get_template_directory_uri() . '/assets/js/customizer.js', array( 'customize-preview' ), '20161626', true );

		wp_localize_script( 'miami_customizer', 'wp_customizer', array(
			'ajax_url' => admin_url( 'admin-ajax.php' ),
			'theme_url' => get_template_directory_uri(),
			'site_name' => get_bloginfo( 'name' )
		));
	}
endif;
add_action( 'customize_preview_init', 'miami_customize_preview_js' );

if ( ! function_exists( 'miami_button_customize_js' ) ) {
	function miami_button_customize_js() {
		wp_enqueue_script( 'miami_customizer', get_template_directory_uri() . '/assets/js/customizer.js', array( 'customize-controls' ), '20161626', true );
	}
}
add_action( 'customize_controls_enqueue_scripts', 'miami_button_customize_js' );