<?php
/**
 * Miami config functions.
 *
 * @package Miami
*/


// after setup theme
if ( ! function_exists( 'miami_after_setup' ) ) {
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function miami_after_setup() {

		load_theme_textdomain( 'miami', get_template_directory() . '/languages' );

		add_image_size('miami_slider_speaker_mini', 150, 100, true );
		add_image_size('miami_slider_speaker_thumb', 200, 121, true );
		add_image_size('miami_slider_speaker_full', 800, 700, true );

		add_image_size('miami_slider_simple_image', 370, 212, true );

		add_image_size('miami_gallery_image_big', 540, 430, true );
		add_image_size('miami_gallery_image_middle', 576, 216, true );
		add_image_size('miami_gallery_image_mini', 281, 218, true );

		add_theme_support('custom-background' );
		add_theme_support('automatic-feed-links' );
		add_theme_support('custom-header');
		add_theme_support('post-thumbnails' );
		add_theme_support('title-tag' );

		add_image_size( 'miami_blog_post', 540, 800, false );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'topleft' => esc_html__( 'Top Left Menu', 'miami' ),
			'topright' => esc_html__( 'Top Right Menu', 'miami' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		/*
		 * Enable support for Post Formats.
		 * See https://developer.wordpress.org/themes/functionality/post-formats/
		 */
		add_theme_support( 'post-formats', array(
			'aside',
			'audio',
			'image',
			'video',
			'quote',
			'link'
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'miami_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );
	}

}
add_action( 'after_setup_theme', 'miami_after_setup' );

if ( ! function_exists( 'miami_fonts_url' ) ) {
	function miami_fonts_url() {
		$font_url = '';

		/*
		Translators: If there are characters in your language that are not supported
		by chosen font(s), translate this to 'off'. Do not translate into your own language.
		 */
		if ( 'off' !== esc_html_x( 'on', 'Google font: on or off', 'miami' ) ) {
			$fonts = array(
				'Ubuntu:300,300italic,400,400italic,500,500italic,700,700italic',
				'Roboto:100,100italic,300,300italic,400,400italic,500,500italic,700,700italic,900,900italic',
				'Raleway:100,100italic,200,200italic,300,300italic,400,400italic,500,500italic,600,600italic,700,700italic,800,800italic,900,900italic',
				'Dancing Script:400,700'
			);

			$font_url = add_query_arg( 'family',
				urlencode( implode('|',$fonts) . "&subset=latin,latin-ext" ), "//fonts.googleapis.com/css" );
		}
		return $font_url;
	}
}


/*
* add icon font to admin
*/
add_action( 'vc_base_register_admin_css', 'miami_regiser_font_et_line_icons' );
if ( ! function_exists( 'miami_regiser_font_et_line_icons' ) ) {
	function miami_regiser_font_et_line_icons() {
		wp_enqueue_style( 'miami_fonts_icons', get_template_directory_uri() . '/assets/css/miami_icons.css' );
	}
}

/**
 * Define base plugins TGM Plugin Activation
 */
require_once get_template_directory() . '/inc/plugins/tgm/class-tgm-plugin-activation.php';
if ( ! function_exists( 'miami_include_required_plugins' ) ) {
	function miami_include_required_plugins() {

		$plugins = array(

			array(
				'name'                => esc_html__('UpQode Google Maps','miami'),
				'slug'                => 'upqode-google-maps',
				'source'             => esc_url( 'https://import.foxthemes.me/plugins/premium-plugins/upqode-google-maps.zip' ),
				'required'            => false,
				'version'             => '1.0.5',
				'force_activation'    => false,
				'force_deactivation'  => false,
			),
			array(
				'name'                => esc_html__('Contact Form DB','miami'),
				'slug'                => 'contact-form-to-db',
				'source'              => 'https://import.foxthemes.me/plugins/miami/contact-form-7-to-database-extension.zip',
				'required'            => false,
				'version'             => '2.10.28',
				'force_activation'    => false,
				'force_deactivation'  => true,
			),
			array(
				'name'                => esc_html__('Contact Form 7','miami'),
				'slug'                => 'contact-form-7',
				'required'            => false,
				'version'             => '',
				'force_activation'    => false,
				'force_deactivation'  => false,
			),
			array(
				'name'                => esc_html__('WooCommerce','miami'),
				'slug'                => 'woocommerce',
				'required'            => false,
				'version'             => '',
				'force_activation'    => false,
				'force_deactivation'  => false,
			),
			array(
				'name'                => esc_html__('Restaurant Reservations','miami'),
				'slug'                => 'restaurant-reservations',
				'required'            => false,
				'version'             => '',
				'force_activation'    => false,
				'force_deactivation'  => false,
			),
			array(
				'name'                => esc_html__('Visual Composer','miami'),
				'slug'                => 'js_composer',
				'required'            => true,
				'version'             => '6.13.0',
				'force_activation'    => false,
				'force_deactivation'  => false,
				'source'              => 'https://import.foxthemes.me/plugins/premium-plugins/js_composer.zip',
			),
			array(
				'name'                => esc_html__('Miami Plugins','miami'),
				'slug'                => 'miami-plugins',
				'required'            => true,
				'version'             => '1.3.5',
				'force_activation'    => false,
				'force_deactivation'  => true,
				'source'              => 'https://import.foxthemes.me/plugins/miami/miami-plugins.zip',
			),
		);

		// Change this to your theme text domain, used for internationalising strings

		/**
		 * Array of configuration settings. Amend each line as needed.
		 * If you want the default strings to be available under your own theme domain,
		 * leave the strings uncommented.
		 * Some of the strings are added into a sprintf, so see the comments at the
		 * end of each line for what each argument will be.
		 */
		$config = array(
			'domain'          => 'miami',                   // Text domain - likely want to be the same as your theme.
			'default_path'    => '',                          // Default absolute path to pre-packaged plugins
			'menu'            => 'tgmpa-install-plugins',     // Menu slug
			'has_notices'     => true,                        // Show admin notices or not
			'is_automatic'    => false,             // Automatically activate plugins after installation or not
			'message'         => '',              // Message to output right before the plugins table
			'strings'         => array(
				'page_title'                      => esc_html__( 'Install Required Plugins', 'miami' ),
				'menu_title'                      => esc_html__( 'Install Plugins', 'miami' ),
				'installing'                      => esc_html__( 'Installing Plugin: %s', 'miami' ), // %1$s = plugin name
				'oops'                            => esc_html__( 'Something went wrong with the plugin API.', 'miami' ),
				'notice_can_install_required'     => _n_noop( 'This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.', 'miami' ), // %1$s = plugin name(s)
				'notice_can_install_recommended'  => _n_noop( 'This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.', 'miami' ), // %1$s = plugin name(s)
				'notice_cannot_install'           => _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.', 'miami' ), // %1$s = plugin name(s)
				'notice_can_activate_required'    => _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.', 'miami' ), // %1$s = plugin name(s)
				'notice_can_activate_recommended' => _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.', 'miami' ), // %1$s = plugin name(s)
				'notice_cannot_activate'          => _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.', 'miami' ), // %1$s = plugin name(s)
				'notice_ask_to_update'            => _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.', 'miami' ), // %1$s = plugin name(s)
				'notice_cannot_update'            => _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.', 'miami' ), // %1$s = plugin name(s)
				'install_link'                    => _n_noop( 'Begin installing plugin', 'Begin installing plugins', 'miami' ),
				'activate_link'                   => _n_noop( 'Activate installed plugin', 'Activate installed plugins', 'miami' ),
				'return'                          => esc_html__( 'Return to Required Plugins Installer', 'miami' ),
				'plugin_activated'                => esc_html__( 'Plugin activated successfully.', 'miami' ),
				'complete'                  	  => esc_html__( 'All plugins installed and activated successfully. %s', 'miami' ), // %1$s = dashboard link
				'nag_type'                  	  => 'updated' // Determines admin notice type - can only be 'updated' or 'error'
			)
		);

		tgmpa( $plugins, $config );
	}
}
add_action( 'tgmpa_register', 'miami_include_required_plugins' );


/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
if ( ! function_exists( 'miami_content_width' ) ) {
	function miami_content_width() {
		$GLOBALS['content_width'] = apply_filters( 'miami_content_width', 1200 );
	}
}
add_action( 'after_setup_theme', 'miami_content_width', 0 );


/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
if ( ! function_exists( 'miami_widgets_init' ) ) {
	function miami_widgets_init() {
		register_sidebar( array(
			'name'          => esc_html__( 'Sidebar', 'miami' ),
			'id'            => 'sidebar-1',
			'description'   => esc_html__( 'Main site sidebar', 'miami' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h2 class="widget-title">',
			'after_title'   => '</h2>',
		) );
	}
}
add_action( 'widgets_init', 'miami_widgets_init' );


/**
 * Enqueue scripts and styles.
 */
if ( ! function_exists( 'miami_scripts' ) ) {
	function miami_scripts() {

		$miami = wp_get_theme();

		wp_enqueue_style( 'bootstrap',          get_template_directory_uri() . '/assets/css/bootstrap.min.css','', apply_filters( 'miami_version_filter', $miami->get( 'Version' )) );
		wp_enqueue_style( 'font-awesome',       get_template_directory_uri() . '/assets/css/font-awesome.min.css','', apply_filters( 'miami_version_filter', $miami->get( 'Version' )));
		wp_enqueue_style( 'idangerous.swiper',  get_template_directory_uri() . '/assets/css/idangerous.swiper.css','', apply_filters( 'miami_version_filter', $miami->get( 'Version' )));
		wp_enqueue_style( 'miami_change-color', get_template_directory_uri() . '/assets/css/change_color.css','', apply_filters( 'miami_version_filter', $miami->get( 'Version' )));
		wp_enqueue_style( 'miami_fonts', 		miami_fonts_url(), '', apply_filters( 'miami_version_filter', $miami->get( 'Version' )) );
		wp_enqueue_style( 'miami_fonts_icons', 	get_template_directory_uri() . '/assets/css/miami_icons.css','', apply_filters( 'miami_version_filter', $miami->get( 'Version' )));
		wp_enqueue_style( 'miami_unit-test',    get_template_directory_uri() . '/assets/css/unit-test.css');
		wp_enqueue_style( 'animate',       		get_template_directory_uri() . '/assets/css/animate.css','', apply_filters( 'miami_version_filter', $miami->get( 'Version' )));
		wp_enqueue_style( 'miami_base-style',	get_template_directory_uri() . '/assets/css/style.css','', apply_filters( 'miami_version_filter', $miami->get( 'Version' )));
		wp_enqueue_style( 'miami_dynamic-css', 	admin_url('admin-ajax.php').'?action=dynamic_css', '', apply_filters( 'miami_version_filter', $miami->get( 'Version' )));

		wp_enqueue_style( 'miami-style', get_stylesheet_uri() );

		$api_key = cs_get_option( 'google_map_api_key', 'AIzaSyA6M45oe9V8IfJfUB6x4k0FKhmEf58nJAs' );

		if( is_single() ) {
			wp_enqueue_script( 'fitvids', get_template_directory_uri() . '/assets/js/jquery.fitvids.js', array('jquery'), apply_filters( 'miami_version_filter', $miami->get( 'Version' ), true ) );
		}

		wp_enqueue_script( 'idangerous_swiper', 	   get_template_directory_uri() . '/assets/js/idangerous.swiper.min.js', array('jquery'), apply_filters( 'miami_version_filter', $miami->get( 'Version' ), true ));
		wp_enqueue_script( 'isotope', 				   get_template_directory_uri() . '/assets/js/isotope.pkgd.min.js', array('jquery'), apply_filters( 'miami_version_filter', $miami->get( 'Version' ), true ));
		wp_enqueue_script( 'imagelightbox', 		   get_template_directory_uri() . '/assets/js/imagelightbox.min.js', array('jquery'), apply_filters( 'miami_version_filter', $miami->get( 'Version' ), true ));
		wp_enqueue_script( 'classycountdown', 		   get_template_directory_uri() . '/assets/js/jquery.classycountdown.min.js', array('jquery'), apply_filters( 'miami_version_filter', $miami->get( 'Version' ), true ));
		wp_enqueue_script( 'knob', 					   get_template_directory_uri() . '/assets/js/jquery.knob.js', array('jquery'), apply_filters( 'miami_version_filter', $miami->get( 'Version' ), true ));
		if(is_ssl()){
			wp_enqueue_script( 'maps', 					   "https://maps.googleapis.com/maps/api/js?key={$api_key}", array(), apply_filters( 'miami_version_filter', $miami->get( 'Version' ), true ));
		}else{
			wp_enqueue_script( 'maps', 					   "http://maps.googleapis.com/maps/api/js?key={$api_key}", array(), apply_filters( 'miami_version_filter', $miami->get( 'Version' ), true ));
		}
		wp_enqueue_script( 'throttle', 				   get_template_directory_uri() . '/assets/js/jquery.throttle.js', array('jquery'), apply_filters( 'miami_version_filter', $miami->get( 'Version' ), true ));
        wp_enqueue_script( 'miami_global', 			   get_template_directory_uri() . '/assets/js/global.js', array('jquery'), apply_filters( 'miami_version_filter', $miami->get( 'Version' ), true ));
		wp_enqueue_script( 'miami_anchors_navigation', get_template_directory_uri() . '/assets/js/anchors.navigation.js', array('jquery'), apply_filters( 'miami_version_filter', $miami->get( 'Version' ), true ));
		wp_enqueue_script( 'miami_customizer', 	 	   get_template_directory_uri() . '/assets/js/customizer.js', array('jquery'), apply_filters( 'miami_version_filter', $miami->get( 'Version' ), true ));
		wp_enqueue_script( 'equalHeights', 			   get_template_directory_uri() . '/assets/js/equalHeightsPlugin.js', array('jquery'), apply_filters( 'miami_version_filter', $miami->get( 'Version' ), true ));
		wp_enqueue_script( 'miami_parallax', 		   get_template_directory_uri() . '/assets/js/parallax.js', array('jquery'), apply_filters( 'miami_version_filter', $miami->get( 'Version' ), true ));
		wp_enqueue_script( 'miami_navigation', 		   get_template_directory_uri() . '/assets/js/navigation.js', array(), apply_filters( 'miami_version_filter', $miami->get( 'Version' ), true ));

		if( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}

		wp_localize_script('miami_global', 'js_data',
			array(
				'ajaxurl' => admin_url( 'admin-ajax.php' ),
				'siteurl' => get_template_directory_uri()
			)
		);

		// add TinyMCE style
		add_editor_style();

		/* Custom JavaScript code */
		$custom_js_code = cs_get_option( 'custom-js' );
		if( ! empty( $custom_js_code ) ) {
			if ( function_exists( 'wp_add_inline_script' ) ) {
				wp_add_inline_script( 'miami_global', $custom_js_code );
			}
		}
	}
}
add_action( 'wp_enqueue_scripts', 'miami_scripts', 1 );

// cs framework missing
if ( ! function_exists( 'cs_get_option' ) ) {
	function cs_get_option( $option = '', $default = '' ) {
		return $default;
	}
}

if ( ! function_exists( 'cs_get_customize_option' ) ) {
	function cs_get_customize_option() {
		return '';
	}
}

// filter style link
if ( ! function_exists( 'miami_style_loader_tag_function' ) ) {
	function miami_style_loader_tag_function( $tag ) {
		//do stuff here to find and replace the rel attribute
		$tag = preg_replace("/media=''/", "", $tag);
		$tag = preg_replace("/rel='stylesheet'/", "rel='stylesheet' property='stylesheet'", $tag);
		return $tag;
	}
}
add_filter('style_loader_tag', 'miami_style_loader_tag_function');

if ( ! function_exists( 'miami_comment' ) ) {
	function miami_comment( $comment, $args, $depth ) {
		$GLOBALS['comment'] = $comment; ?>

		<div id="comment-<?php comment_ID(); ?>" <?php comment_class('news-comments comment-entry'); ?>>
			<div class="animatedBlock com-content">
				<?php echo get_avatar( $comment, '80' ); ?>
				<p class="name">
					<?php comment_author( get_comment_ID() ) ?>
				</p>
				<p class="date"><i class="fa fa-calendar" aria-hidden="true"></i><?php comment_date( get_option( 'date_format' ) );?></p>

				<?php if ( $comment->comment_approved == '0' ) : ?>
					<div class="alert alert-info">
						<p><?php esc_html_e( 'Your comment is awaiting moderation.', 'miami' ) ?></p>
					</div>
				<?php endif; ?>

				<div class="text">
					<?php $comment_text = get_comment_text();
						$trimmed = trim( $comment_text, " " );
						echo wpautop( $trimmed );
					?>
				</div>
				<p><?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?></p>
			</div>
		<?php
	}
}


// Add backend styles for Gutenberg.
add_action( 'enqueue_block_editor_assets', 'miami_add_gutenberg_assets' );

function miami_add_gutenberg_assets() {
	// Load the theme styles within Gutenberg.
	wp_enqueue_style( 'miami-fonts', miami_fonts_url(), array(), '1.0.0' );
	wp_enqueue_style( 'miami-gutenberg', get_theme_file_uri( '/assets/css/gutenberg-editor-style.min.css' ), false );
}
