<?php
/**
 * The main template file.
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Miami
 */
get_header(); 

//titles blog
$blog_title = cs_get_option( 'blog_title' );
$blog_desc 	= cs_get_option( 'blog_desc' );
$blog_bg 	= cs_get_option( 'blog_bg_image' );

// show/hide sidebar
$hide_sidebar = cs_get_option('show_sidebar');
if ( $hide_sidebar === true ) {
	$base_column = ' col-md-12';
} else {
	$base_column = 'col-md-8';
}

$height = '';
if ( empty( $blog_bg ) ) {
	$height = 'auto';
} ?>

<div>
	<?php if ( ! empty( $blog_bg ) || ( ( ! empty( $blog_title ) ) ) || ( ! empty( $blog_desc ) ) ) { ?>

		<div class="blog-banner <?php echo esc_attr($height); ?>">
			<?php if ( ! empty( $blog_bg ) ) { ?>
				<img src="<?php echo esc_url( $blog_bg ) ?>" alt="<?php echo esc_attr( $blog_title ) ?>" class="s-img-switch">
			<?php } ?>

			<?php if ( is_home() && ( ( ! empty( $blog_title ) ) ) || ( ! empty( $blog_desc ) ) ) { ?>
				<div class="block-header <?php echo esc_attr( $height ); ?> vertical-align">

					<?php if( ! empty( $blog_title ) ) { ?>
						<h2 class="block-title"><?php echo esc_html( $blog_title ); ?></h2>
					<?php } else { ?>
						<h2 class="block-title"><?php single_post_title(); ?></h2>
					<?php } ?>

					<?php if ( is_home() && ( ! empty( $blog_desc ) ) ) { ?>
						<div class="block-text"><?php echo wp_kses_post( do_shortcode( $blog_desc ) ); ?></div>
					<?php } ?>

				</div>
			<?php } ?>
		</div>

	<?php } else { ?>

		<div class="blog-banner <?php echo esc_attr( $height ); ?>">

			<?php if ( ! empty( $blog_bg ) ) { ?>
				<img src="<?php echo esc_url( $blog_bg ); ?>" alt="<?php echo esc_attr( $blog_title ) ?>" class="s-img-switch">
			<?php } ?>

			<div class="block-header <?php echo esc_attr( $height ); ?> vertical-align">
				<h2 class="block-title"><?php echo esc_html_e( 'Blog', 'miami' ); ?></h2>
			</div>
		</div>

	<?php } ?>

	<div class="container blog-list">
		<div class="row">
			<div class="<?php echo esc_attr( $base_column ); ?> ">
				<?php if ( have_posts() ) { ?>
					<div class="container-fluid no-padding">
						<div class="row">
							<div class="isotope-container-blog">

								<?php
								// Start the loop.
								while ( have_posts() ) {

									the_post();

									// get post format
									$format = get_post_format();
									$format = ( $format === false) ? 'default' : $format;
									$classes_post =  'col-xs-12 col-sm-6 blog-content-item'; ?>

									<div <?php post_class( esc_attr( $classes_post ) ); ?> >

										<?php
										if( is_sticky() ){  ?>
											<i title="<?php esc_html_e( 'Sticky Post', 'miami' ); ?>" class="sticky-icon fa fa-thumb-tack fa-2x"></i>
										<?php }
										// get template format
										get_template_part('template-parts/content', $format); ?>

									</div>
								<?php } /* End the loop */ ?>

							</div>
						</div>
					</div>

					<?php
					// Previous/next page navigation.
					the_posts_pagination( array(
						'mid_size'           => 1,
						'prev_text'          => esc_html__( 'Previous','miami'),
						'next_text'          => esc_html__( 'Next','miami' ),
						'screen_reader_text' => ' ',
					));

					// If no content, include the "No posts found" template.
				} else {
					get_template_part( 'template-parts/content', 'none' );
				} ?>

			</div>
			<?php if( $hide_sidebar !== true ) { ?>
				<div class="col-md-4">
					<?php get_sidebar(); ?>
				</div>
			<?php } ?>
		</div>
	</div>
</div>
<?php get_footer();