<?php
/**
 * The template for displaying all single posts.
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/#single-post
 *
 * @package Miami
 */

get_header(); 

// show/hide sidebar
$hide_sidebar   = cs_get_option('show_sidebar');
$hide_animation = cs_get_option( 'animation' );

$base_column = 'col-md-12';
if ( $hide_sidebar == false ) {
	$base_column = 'col-md-8';
}

$add_animation = '';
if ( $hide_animation != true ) {
	$add_animation = 'add_animation';
} 
$add_animation .= ! empty( get_the_title() ) ? '' : ' has-no-title'; ?>

<div id="post-<?php the_ID(); ?>" <?php post_class( 'single-page' ); ?>>
	<div class="container <?php echo esc_attr( $add_animation ); ?>">
		<div class="row">
			<div class="col-xs-12">
				<!-- Post title -->
				<?php the_title( '<h1 class="block-title">', '</h1>' ); ?>
			</div>
		</div>
		<div class="row">
			<div class="col-xs-12">
				<div class="wrapper-image">
					<?php if ( get_post_format() != 'video' ) {
						// thumbnail
						the_post_thumbnail('large', array('class' => 's-img-switch', 'data-s-hidden'=> '1' ) );
					} ?>
				</div>
			</div>
		</div>
		<div class="row post-content">
			<div class="content <?php echo esc_attr( $base_column ); ?>">
				<?php while ( have_posts() ) {
					the_post();

					// Post content.
					the_content();

					wp_link_pages('link_before=<span class="pages">&link_after=</span>&before=<div class="post-nav"> <span>' . esc_html__( "Page:", 'miami' ) . ' </span> &after=</div>'); ?>

					<!-- Post categories -->
					<div class="single-category">
						<?php the_category(''); ?>
					</div>

					<?php if( has_tag() ) { ?>
						<!-- Post tags -->
						<div class="single-category tags">
							<?php the_tags(); ?>
						</div>

					<?php } ?>

					<div class="pagination-single clearfix">
						<?php 	// Previous/next post navigation.
						the_post_navigation( array(
							'next_text' => '<span class="meta-nav next" aria-hidden="true">' . esc_html__( 'Next', 'miami' ) . '<i class="fa fa-angle-right" aria-hidden="true"></i></span> ',
							'prev_text' => '<span class="meta-nav prev" aria-hidden="true"><i class="fa fa-angle-left" aria-hidden="true"></i>' . esc_html__( 'Previous', 'miami' ) . '</span> ',
						) ); ?>
					</div>

					<?php
					
					// If comments are open or we have at least one comment, load up the comment template.
					if ( comments_open() || get_comments_number() ) :
						comments_template();
					endif; ?>

				<?php } // End of the loop. ?>
			</div>
			<?php if( $hide_sidebar == false ) { ?>
				<div class="col-md-4">
					<?php get_sidebar(); ?>
				</div>
			<?php } ?>
		</div>
	</div>

</div><!-- .container -->
<?php get_footer();